diff --git a/plugins/talk-plugin-profile-data/client/containers/DeleteMyAccount.js b/plugins/talk-plugin-profile-data/client/containers/DeleteMyAccount.js
index 84d0b9a5c..0a81107f5 100644
--- a/plugins/talk-plugin-profile-data/client/containers/DeleteMyAccount.js
+++ b/plugins/talk-plugin-profile-data/client/containers/DeleteMyAccount.js
@@ -16,6 +16,9 @@ const withData = withFragments({
me {
scheduledDeletionDate
}
+ settings {
+ organizationContactEmail
+ }
}
`,
});
diff --git a/plugins/talk-plugin-profile-data/client/mutations.js b/plugins/talk-plugin-profile-data/client/mutations.js
index 3ae0d88f7..c7ca68950 100644
--- a/plugins/talk-plugin-profile-data/client/mutations.js
+++ b/plugins/talk-plugin-profile-data/client/mutations.js
@@ -46,7 +46,7 @@ export const withRequestAccountDeletion = withMutation(
});
const scheduledDeletionDate = moment()
- .add(12, 'hours')
+ .add(24, 'hours')
.toDate();
const data = update(prev, {
diff --git a/plugins/talk-plugin-profile-data/client/translations.yml b/plugins/talk-plugin-profile-data/client/translations.yml
index 839154446..2a0c9e334 100644
--- a/plugins/talk-plugin-profile-data/client/translations.yml
+++ b/plugins/talk-plugin-profile-data/client/translations.yml
@@ -26,25 +26,26 @@ en:
changed_your_mind: "Changed your mind?"
simply_go_to: "Simply go to your account again before this time and click"
tell_us_why: "Tell us why"
- feedback_copy: "We'd like to know why you chose to delete your account. Send us feedback on our comment system by emailing."
+ feedback_copy: "We would like to know why you chose to delete your account. Send us feedback on our comment system by emailing"
done: "Done"
cancel: "Cancel"
proceed: "Proceed"
input_is_not_correct: "The input is not correct"
- you_are_attempting: "You are attempting to delete your account. This means:"
- item_1: "All of your comments are removed from this site"
- item_2: "All of your comments are deleted from our database"
- item_3: "Your username and email address are removed from our system"
- step1:
+ step_0:
+ you_are_attempting: "You are attempting to delete your account. This means:"
+ item_1: "All of your comments are removed from this site"
+ item_2: "All of your comments are deleted from our database"
+ item_3: "Your username and email address are removed from our system"
+ step_1:
subtitle: "When will my account be deleted?"
description: "Your account will be deleted 24 hours after your request has been submitted."
subtitle_2: "Can I still write comments until my account is deleted?"
description_2: "No. Once you have requested account deletion, you can no longer write comments, reply to comments, or select reactions."
- step2:
+ step_2:
description: "Before your account is deleted, we recommend you download your comment history for your records. After your account is deleted, you will be unable to request your comment history."
to_download: "To download your comment history go to:"
path: "My Profile > Download My Comment History"
- step3:
+ step_3:
subtitle: "Are you sure you want to delete your account?"
description: "To confirm you would like to delete your account please type in the following phrase into the text box below:"
type_to_confirm: "Type phrase below to confirm"
diff --git a/plugins/talk-plugin-profile-data/server/mutators.js b/plugins/talk-plugin-profile-data/server/mutators.js
index d3785c951..c895e51d8 100644
--- a/plugins/talk-plugin-profile-data/server/mutators.js
+++ b/plugins/talk-plugin-profile-data/server/mutators.js
@@ -93,16 +93,16 @@ async function sendDownloadLink(ctx) {
}
// requestDeletion will schedule the current user to have their account deleted
// by setting the `scheduledDeletionDate` on the user 12 hours from now.
async function requestDeletion({ user, connectors: { models: { User } } }) {
// Ensure the user doesn't already have a deletion scheduled.
if (get(user, 'metadata.scheduledDeletionDate')) {
throw new ErrDeletionAlreadyScheduled();
}
// Get the date in the future 12 hours from now.
const scheduledDeletionDate = moment()
- .add(12, 'hours')
+ .add(24, 'hours')
.toDate();
// Amend the scheduledDeletionDate on the user.
@@ -93,16 +93,16 @@ async function sendDownloadLink(ctx) {
}
// requestDeletion will schedule the current user to have their account deleted
-// by setting the `scheduledDeletionDate` on the user 12 hours from now.
+// by setting the `scheduledDeletionDate` on the user 24 hours from now.
async function requestDeletion({ user, connectors: { models: { User } } }) {
// Ensure the user doesn't already have a deletion scheduled.
@@ -93,16 +93,16 @@ async function sendDownloadLink(ctx) {
throw new ErrDeletionAlreadyScheduled();
}
- // Get the date in the future 12 hours from now.
+ // Get the date in the future 24 hours from now.
const scheduledDeletionDate = moment()